@@ -67,6 +67,7 @@ long DVDWindow::onCmdOptions(FXObject*,FXSelector,void*){
   FXDataTarget target_screensaver(disable_screensaver);
   FXDataTarget target_audiostream(auto_audiostream);
   FXDataTarget target_screenshot(screenshot_with_spu);
+	FXDataTarget dt_timeskip(timeskip);
 
   FXDialogBox dialog(this,"Preferences",DECOR_ALL);
   FXVerticalFrame * main=new FXVerticalFrame(&dialog,LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0,0,0,0,0);
@@ -134,7 +135,6 @@ long DVDWindow::onCmdOptions(FXObject*,FXSelector,void*){
   new FXTextField(matrix,15,&target_dvdbookmarkdir,FXDataTarget::ID_VALUE,LAYOUT_FILL_X|FRAME_SUNKEN|FRAME_THICK|LAYOUT_FILL_COLUMN);
   new FXButton(matrix,"...\tBrowse",NULL,this,ID_GETBOOKMARKDIR);
 
-
   new FXLabel(matrix,"Player Region",NULL,labelstyle);
   FXListBox * regionlist = new FXListBox(matrix,NULL,0,listboxstyle);
   new FXFrame(matrix,FRAME_NONE);
@@ -216,6 +216,9 @@ long DVDWindow::onCmdOptions(FXObject*,FXSelector,void*){
   aspectlist->setNumVisible(4);
   aspectlist->disable();
 
+	new FXLabel(matrix,"Skip Time in Seconds",NULL,labelstyle);
+	new FXSpinner(matrix,3,&dt_timeskip,FXDataTarget::ID_VALUE,LAYOUT_FILL_X|FRAME_SUNKEN|FRAME_THICK);
+  new FXFrame(matrix,FRAME_NONE);
 
 
 #ifdef HAVE_DXR3
@@ -398,84 +401,83 @@ long DVDWindow::onCmdOptions(FXObject*,FXSelector,void*){
   matrix=new FXMatrix(frame4,2,MATRIX_BY_COLUMNS|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0);
 
   new FXLabel(matrix,"Fullscreen",NULL,labelstyle);
-  txtfld=new FXTextField(matrix,8,this,DVDWindow::ID_SHORTCUT_FULLSCREEN,textfieldstyle);
+  txtfld=new FXTextField(matrix,4,this,DVDWindow::ID_SHORTCUT_FULLSCREEN,textfieldstyle);
   txtfld->setText(getApp()->reg().readStringEntry("HotKeys","Fullscreen",DEFAULT_SHORTCUT_FULLSCREEN));
 
   new FXLabel(matrix,"Bring GUI to Top",NULL,labelstyle);
-  txtfld=new FXTextField(matrix,8,this,DVDWindow::ID_SHORTCUT_RAISE,textfieldstyle);
+  txtfld=new FXTextField(matrix,4,this,DVDWindow::ID_SHORTCUT_RAISE,textfieldstyle);
   txtfld->setText(getApp()->reg().readStringEntry("HotKeys","Raise",DEFAULT_SHORTCUT_RAISE));
 
   new FXLabel(matrix,"TitleMenu",NULL,labelstyle);
-  txtfld=new FXTextField(matrix,8,this,DVDWindow::ID_SHORTCUT_TITLEMENU,textfieldstyle);
+  txtfld=new FXTextField(matrix,4,this,DVDWindow::ID_SHORTCUT_TITLEMENU,textfieldstyle);
   txtfld->setText(getApp()->reg().readStringEntry("HotKeys","TitleMenu",DEFAULT_SHORTCUT_TITLEMENU));
 
   new FXLabel(matrix,"RootMenu",NULL,labelstyle);
-  txtfld=new FXTextField(matrix,8,this,DVDWindow::ID_SHORTCUT_ROOTMENU,textfieldstyle);
+  txtfld=new FXTextField(matrix,4,this,DVDWindow::ID_SHORTCUT_ROOTMENU,textfieldstyle);
   txtfld->setText(getApp()->reg().readStringEntry("HotKeys","RootMenu",DEFAULT_SHORTCUT_ROOTMENU));
 
   new FXLabel(matrix,"AudioMenu",NULL,labelstyle);
-  txtfld=new FXTextField(matrix,8,this,DVDWindow::ID_SHORTCUT_AUDIOMENU,textfieldstyle);
+  txtfld=new FXTextField(matrix,4,this,DVDWindow::ID_SHORTCUT_AUDIOMENU,textfieldstyle);
   txtfld->setText(getApp()->reg().readStringEntry("HotKeys","AudioMenu",DEFAULT_SHORTCUT_AUDIOMENU));
 
   new FXLabel(matrix,"AngleMenu",NULL,labelstyle);
-  txtfld=new FXTextField(matrix,8,this,DVDWindow::ID_SHORTCUT_ANGLEMENU,textfieldstyle);
+  txtfld=new FXTextField(matrix,4,this,DVDWindow::ID_SHORTCUT_ANGLEMENU,textfieldstyle);
   txtfld->setText(getApp()->reg().readStringEntry("HotKeys","AngleMenu",DEFAULT_SHORTCUT_ANGLEMENU));
 
   new FXLabel(matrix,"SubtitleMenu",NULL,labelstyle);
-  txtfld=new FXTextField(matrix,8,this,DVDWindow::ID_SHORTCUT_SUBPICTUREMENU,textfieldstyle);
+  txtfld=new FXTextField(matrix,4,this,DVDWindow::ID_SHORTCUT_SUBPICTUREMENU,textfieldstyle);
   txtfld->setText(getApp()->reg().readStringEntry("HotKeys","SubtitleMenu",DEFAULT_SHORTCUT_SUBPICTUREMENU));
 
   new FXLabel(matrix,"Navigate Up",NULL,labelstyle);
-  txtfld=new FXTextField(matrix,8,this,DVDWindow::ID_SHORTCUT_UP,textfieldstyle);
+  txtfld=new FXTextField(matrix,4,this,DVDWindow::ID_SHORTCUT_UP,textfieldstyle);
   txtfld->setText(getApp()->reg().readStringEntry("HotKeys","NavUp",DEFAULT_SHORTCUT_NAVUP));
 
   new FXLabel(matrix,"Navigate Down",NULL,labelstyle);
-  txtfld=new FXTextField(matrix,8,this,DVDWindow::ID_SHORTCUT_DOWN,textfieldstyle);
+  txtfld=new FXTextField(matrix,4,this,DVDWindow::ID_SHORTCUT_DOWN,textfieldstyle);
   txtfld->setText(getApp()->reg().readStringEntry("HotKeys","NavDown",DEFAULT_SHORTCUT_NAVDOWN));
 
   matrix=new FXMatrix(frame4,2,MATRIX_BY_COLUMNS|LAYOUT_FILL_X|LAYOUT_FILL_Y,0,0,0,0);
 
   new FXLabel(matrix,"Pause",NULL,labelstyle);
-  txtfld=new FXTextField(matrix,8,this,DVDWindow::ID_SHORTCUT_PAUSE,textfieldstyle);
+  txtfld=new FXTextField(matrix,4,this,DVDWindow::ID_SHORTCUT_PAUSE,textfieldstyle);
   txtfld->setText(getApp()->reg().readStringEntry("HotKeys","Pause",DEFAULT_SHORTCUT_PAUSE));
 
   new FXLabel(matrix,"Stop",NULL,labelstyle);
-  txtfld=new FXTextField(matrix,8,this,DVDWindow::ID_SHORTCUT_STOP,textfieldstyle);
+  txtfld=new FXTextField(matrix,4,this,DVDWindow::ID_SHORTCUT_STOP,textfieldstyle);
   txtfld->setText(getApp()->reg().readStringEntry("HotKeys","Stop",DEFAULT_SHORTCUT_STOP));
 
   new FXLabel(matrix,"Next Chapter",NULL,labelstyle);
-  txtfld=new FXTextField(matrix,8,this,DVDWindow::ID_SHORTCUT_NEXT,textfieldstyle);
+  txtfld=new FXTextField(matrix,4,this,DVDWindow::ID_SHORTCUT_NEXT,textfieldstyle);
   txtfld->setText(getApp()->reg().readStringEntry("HotKeys","Next",DEFAULT_SHORTCUT_NEXT));
 
   new FXLabel(matrix,"Previous Chapter",NULL,labelstyle);
-  txtfld=new FXTextField(matrix,8,this,DVDWindow::ID_SHORTCUT_PREVIOUS,textfieldstyle);
+  txtfld=new FXTextField(matrix,4,this,DVDWindow::ID_SHORTCUT_PREVIOUS,textfieldstyle);
   txtfld->setText(getApp()->reg().readStringEntry("HotKeys","Previous",DEFAULT_SHORTCUT_PREVIOUS));
 
   new FXLabel(matrix,"Search Forward",NULL,labelstyle);
-  txtfld=new FXTextField(matrix,8,this,DVDWindow::ID_SHORTCUT_SEARCHFORWARD,textfieldstyle);
+  txtfld=new FXTextField(matrix,4,this,DVDWindow::ID_SHORTCUT_SEARCHFORWARD,textfieldstyle);
   txtfld->setText(getApp()->reg().readStringEntry("HotKeys","SearchForward",DEFAULT_SHORTCUT_SEARCHFORWARD));
 
   new FXLabel(matrix,"Search Backward",NULL,labelstyle);
-  txtfld=new FXTextField(matrix,8,this,DVDWindow::ID_SHORTCUT_SEARCHBACKWARD,textfieldstyle);
+  txtfld=new FXTextField(matrix,4,this,DVDWindow::ID_SHORTCUT_SEARCHBACKWARD,textfieldstyle);
   txtfld->setText(getApp()->reg().readStringEntry("HotKeys","SearchBackward",DEFAULT_SHORTCUT_SEARCHBACKWARD));
 
   new FXLabel(matrix,"Enter/Activate",NULL,labelstyle);
-  txtfld=new FXTextField(matrix,8,this,DVDWindow::ID_SHORTCUT_ENTER,textfieldstyle);
+  txtfld=new FXTextField(matrix,4,this,DVDWindow::ID_SHORTCUT_ENTER,textfieldstyle);
   txtfld->setText(getApp()->reg().readStringEntry("HotKeys","Enter",DEFAULT_SHORTCUT_ENTER));
 
   new FXLabel(matrix,"Navigate Left",NULL,labelstyle);
-  txtfld=new FXTextField(matrix,8,this,DVDWindow::ID_SHORTCUT_LEFT,textfieldstyle);
+  txtfld=new FXTextField(matrix,4,this,DVDWindow::ID_SHORTCUT_LEFT,textfieldstyle);
   txtfld->setText(getApp()->reg().readStringEntry("HotKeys","NavLeft",DEFAULT_SHORTCUT_NAVLEFT));
 
   new FXLabel(matrix,"Navigate Right",NULL,labelstyle);
-  txtfld=new FXTextField(matrix,8,this,DVDWindow::ID_SHORTCUT_RIGHT,textfieldstyle);
+  txtfld=new FXTextField(matrix,4,this,DVDWindow::ID_SHORTCUT_RIGHT,textfieldstyle);
   txtfld->setText(getApp()->reg().readStringEntry("HotKeys","NavRight",DEFAULT_SHORTCUT_NAVRIGHT));
 
   new FXLabel(matrix,"Take Screenshot",NULL,labelstyle);
-  txtfld=new FXTextField(matrix,8,this,DVDWindow::ID_SHORTCUT_RIGHT,textfieldstyle);
+  txtfld=new FXTextField(matrix,4,this,DVDWindow::ID_SHORTCUT_RIGHT,textfieldstyle);
   txtfld->setText(getApp()->reg().readStringEntry("HotKeys","SnapShot",DEFAULT_SHORTCUT_SNAPSHOT));
 
-
   // Bottom part
   FXHorizontalFrame *closebox=new FXHorizontalFrame(main,LAYOUT_BOTTOM|LAYOUT_FILL_X|PACK_UNIFORM_WIDTH,0,0,0,0,0,0,0,0);
   new FXButton(closebox," &Accept ",NULL,&dialog,FXDialogBox::ID_ACCEPT,BUTTON_INITIAL|BUTTON_DEFAULT|LAYOUT_RIGHT|FRAME_RAISED|FRAME_THICK,0,0,0,0, 20,20);
@@ -501,9 +503,7 @@ long DVDWindow::onCmdOptions(FXObject*,FXSelector,void*){
     getApp()->reg().writeStringEntry("OGLE","default menu language",def_menulang.text());
 
 
-#ifdef HAVE_DXR3
-#endif
-    if (!FXFile::exists(bookmarkdir)){
+    if (!FXStat::exists(bookmarkdir)){
       bookmarkdir=bookmarkdir_backup;
       }
 
